@@ -11,7 +11,7 @@
 //! * Uses [`downcast-rs`] instead of [`mopa`] for downcasting types.
 //! * Adds `Debug` and `PartialEq` implementations for borrow types when the
 //!   resource type implements those traits.
-//! * Returns `None` instead of panicking for `try_borrow*` functions when the
+//! * Returns `Err` instead of panicking for `try_borrow*` functions when the
 //!   resource is already borrowed.
 //!
 //! ## Usage
@@ -19,11 +19,11 @@
 //! Add the following to `Cargo.toml`
 //!
 //! ```toml
-//! resman = "0.7.0"
+//! resman = "0.9.0"
 //!
 //! # or
-//! resman = { version = "0.7.0", features = ["debug"] }
-//! resman = { version = "0.7.0", features = ["fn_res"] }
+//! resman = { version = "0.9.0", features = ["debug"] }
+//! resman = { version = "0.9.0", features = ["fn_res"] }
 //! ```
 //!
 //! In code:
@@ -159,6 +159,12 @@
 //! Use [`FnRes::try_call`] for a non-panicking version, which will return a
 //! [`BorrowFail`] error if there is an overlapping borrow conflict at runtime.
 //!
+//! #### `"fn_meta"`:
+//!
+//! Adds [`FnMeta`] as an implied trait to [`FnRes`]. This means function
+//! metadata can be queried for any `FnRes`.
+//!
+//!
 //! ## See Also
 //!
 //! * [`anymap`]: Map of any type, without multiple mutable borrows.
@@ -168,7 +174,10 @@
 //! [`anymap`]: https://github.com/chris-morgan/anymap
 //! [`downcast-rs`]: https://github.com/marcianx/downcast-rs
 //! [`mopa`]: https://github.com/chris-morgan/mopa
+//! [`rt_map`]: https://github.com/azriel91/rt_map
 //! [`shred`]: https://github.com/amethyst/shred
+//!
+//! [`FnMeta`]: fn_meta::FnMeta
 
 pub use crate::{
     entry::Entry, r#ref::Ref, ref_mut::RefMut, resource::Resource, resources::Resources,
@@ -176,6 +185,9 @@ pub use crate::{
 
 pub use rt_map::BorrowFail;
 
+#[cfg(feature = "fn_meta")]
+pub use fn_meta;
+
 mod entry;
 mod r#ref;
 mod ref_mut;
@@ -184,11 +196,14 @@ mod resources;
 
 #[cfg(feature = "fn_res")]
 pub use crate::{
-    fn_res::{FnRes, IntoFnRes},
+    fn_res::FnRes,
     fn_resource::{FnResource, IntoFnResource},
+    into_fn_res::IntoFnRes,
 };
 
 #[cfg(feature = "fn_res")]
 mod fn_res;
 #[cfg(feature = "fn_res")]
 mod fn_resource;
+#[cfg(feature = "fn_res")]
+mod into_fn_res;
